@@ -1,14 +1,15 @@
 #!/usr/bin/env python
+import sys
+
 from .fpdf import (
     FPDF,
-    FPDF_CACHE_DIR as _FPDF_CACHE_DIR,
-    FPDF_CACHE_MODE as _FPDF_CACHE_MODE,
     FPDF_FONT_DIR as _FPDF_FONT_DIR,
     FPDF_VERSION as _FPDF_VERSION,
     SYSTEM_TTFONTS as _SYSTEM_TTFONTS,
 )
 from .html import HTMLMixin
 from .template import Template
+from .util.deprecation import WarnOnDeprecatedModuleAttributes
 
 FPDF_VERSION = _FPDF_VERSION
 """Current FPDF Version, also available via `__version__` (which is read by `setup.py`):
@@ -20,13 +21,6 @@ FPDF_VERSION = _FPDF_VERSION
 </pre>
 """
 
-FPDF_CACHE_MODE = _FPDF_CACHE_MODE
-
-FPDF_CACHE_DIR = _FPDF_CACHE_DIR
-"""This is the directory where pickle files for TTF font files are kept
-containing meta-data and stuffs.
-"""
-
 FPDF_FONT_DIR = _FPDF_FONT_DIR
 """This is the location of where to look for fonts."""
 
@@ -34,6 +28,8 @@ SYSTEM_TTFONTS = _SYSTEM_TTFONTS
 """This is the directory searched for fonts when a font file path is not given.
 """
 
+sys.modules[__name__].__class__ = WarnOnDeprecatedModuleAttributes
+
 __license__ = "LGPL 3.0"
 
 __version__ = FPDF_VERSION
@@ -49,8 +45,6 @@ __all__ = [
     "HTMLMixin",
     # FPDF Constants
     "FPDF_VERSION",
-    "FPDF_CACHE_MODE",
-    "FPDF_CACHE_DIR",
     "FPDF_FONT_DIR",
     "SYSTEM_TTFONTS",
 ]
