@@ -16,11 +16,11 @@
 #
 # ******************************************************************************
 
-from struct import error as StructError, pack, unpack
 import re
 import warnings
-from .util import b, substr
+from struct import error as StructError, pack, unpack
 
+from .util import b, substr
 
 # Define the value used in the "head" table of a created TTF file
 # 0x74727565 "true" for Mac
@@ -29,7 +29,6 @@ from .util import b, substr
 # when read by Adobe Reader on a Windows PC(!)
 _TTF_MAC_HEADER = False
 
-
 # TrueType Font Glyph operators
 GF_WORDS = 1 << 0
 GF_SCALE = 1 << 3
@@ -51,7 +50,7 @@ def sub32(x, y):
         xhi += 1 << 16
     reshi = xhi - yhi
     reshi = reshi & 0xFFFF
-    return (reshi, reslo)
+    return reshi, reslo
 
 
 def calcChecksum(data):
@@ -63,14 +62,16 @@ def calcChecksum(data):
         hi += (data[i] << 8) + data[i + 1]
         lo += (data[i + 2] << 8) + data[i + 3]
         hi += lo >> 16
-        lo = lo & 0xFFFF
-        hi = hi & 0xFFFF
-    return (hi, lo)
+        lo &= 0xFFFF
+        hi &= 0xFFFF
+    return hi, lo
 
 
 class TTFontFile:
     def __init__(self):
-        self.maxStrLenRead = 200000  # Maximum size of glyf table to read in as string (otherwise reads each glyph from file)
+        # Maximum size of glyph table to read in as string
+        # (otherwise reads each glyph from file)
+        self.maxStrLenRead = 200000
 
     def getMetrics(self, file):
         self.filename = file
@@ -89,7 +90,7 @@ class TTFontFile:
             if version == 0x74746366:
                 raise RuntimeError("ERROR - TrueType Fonts Collections not supported")
             if version not in (0x00010000, 0x74727565):
-                raise RuntimeError("Not a TrueType font: version=0x%x" % version)
+                raise RuntimeError(f"Not a TrueType font: version=0x{version:x}")
             self.readTableDirectory()
             self.extractInfo()
 
@@ -102,17 +103,18 @@ class TTFontFile:
         self.rangeShift = self.read_ushort()
         self.tables = {}
         for _ in range(self.numTables):
-            record = {}
-            record["tag"] = self.read_tag()
-            record["checksum"] = (self.read_ushort(), self.read_ushort())
-            record["offset"] = self.read_ulong()
-            record["length"] = self.read_ulong()
+            record = {
+                "tag": self.read_tag(),
+                "checksum": (self.read_ushort(), self.read_ushort()),
+                "offset": self.read_ulong(),
+                "length": self.read_ulong(),
+            }
             self.tables[record["tag"]] = record
 
     def get_table_pos(self, tag):
         offset = self.tables[tag]["offset"]
         length = self.tables[tag]["length"]
-        return (offset, length)
+        return offset, length
 
     def seek(self, pos):
         self._pos = pos
@@ -149,9 +151,7 @@ class TTFontFile:
         self._pos += 4
         s = self.fh.read(4)
         # if large uInt32 as an integer, PHP converts it to -ve
-        return (
-            s[0] * 16777216 + (s[1] << 16) + (s[2] << 8) + s[3]
-        )  #     16777216  = 1<<24
+        return s[0] * 16777216 + (s[1] << 16) + (s[2] << 8) + s[3]  # 16777216  = 1<<24
 
     def get_ushort(self, pos):
         self.fh.seek(pos)
@@ -176,7 +176,7 @@ class TTFontFile:
         (pos, length) = self.get_table_pos(tag)
         if length == 0:
             raise RuntimeError(
-                "Truetype font (" + self.filename + "): error reading table: " + tag
+                f"Truetype font ({self.filename}): error reading table: {tag}"
             )
         self.fh.seek(pos)
         return self.fh.read(length)
@@ -186,26 +186,19 @@ class TTFontFile:
             data = self.splice(data, 8, b("\0\0\0\0"))
         self.otables[tag] = data
 
-    ############################################/
-    ############################################/
-
-    ############################################/
-
     def extractInfo(self):
-        #################/
         # name - Naming table
-        #################/
         self.sFamilyClass = 0
         self.sFamilySubClass = 0
 
         name_offset = self.seek_table("name")
         fmt = self.read_ushort()
         if fmt != 0:
-            raise RuntimeError("Unknown name table format " + fmt)
+            raise RuntimeError(f"Unknown name table format {fmt}")
         numRecords = self.read_ushort()
         string_data_offset = name_offset + self.read_ushort()
         names = {1: "", 2: "", 3: "", 4: "", 6: ""}
-        K = list(names.keys())
+        K = list(names)
         nameCount = len(names)
         for _ in range(numRecords):
             platformId = self.read_ushort()
@@ -260,32 +253,18 @@ class TTFontFile:
         if not psName:
             raise RuntimeError("Could not find PostScript font name")
         self.name = psName
-        if names[1]:
-            self.familyName = names[1]
-        else:
-            self.familyName = psName
-        if names[2]:
-            self.styleName = names[2]
-        else:
-            self.styleName = "Regular"
-        if names[4]:
-            self.fullName = names[4]
-        else:
-            self.fullName = psName
-        if names[3]:
-            self.uniqueFontID = names[3]
-        else:
-            self.uniqueFontID = psName
+        self.familyName = names[1] or psName
+        self.styleName = names[2] or "Regular"
+        self.fullName = names[4] or psName
+        self.uniqueFontID = names[3] or psName
         if names[6]:
             self.fullName = names[6]
 
-        #################/
         # head - Font header table
-        #################/
         self.seek_table("head")
         self.skip(18)
         self.unitsPerEm = unitsPerEm = self.read_ushort()
-        scale = 1000 / float(unitsPerEm)
+        scale = 1000 / unitsPerEm
         self.skip(16)
         xMin = self.read_short()
         yMin = self.read_short()
@@ -297,12 +276,11 @@ class TTFontFile:
         indexToLocFormat = self.read_ushort()
         glyphDataFormat = self.read_ushort()
         if glyphDataFormat != 0:
-            raise RuntimeError("Unknown glyph data format " + glyphDataFormat)
+            raise RuntimeError(f"Unknown glyph data format {glyphDataFormat}")
 
-        #################/
         # hhea metrics table
-        #################/
-        # ttf2t1 seems to use this value rather than the one in OS/2 - so put in for compatibility
+        # ttf2t1 seems to use this value rather than the one in OS/2 - so put in for
+        # compatibility
         if "hhea" in self.tables:
             self.seek_table("hhea")
             self.skip(4)
@@ -311,9 +289,7 @@ class TTFontFile:
             self.ascent = hheaAscender * scale
             self.descent = hheaDescender * scale
 
-        #################/
         # OS/2 - OS/2 and Windows metrics table
-        #################/
         if "OS/2" in self.tables:
             self.seek_table("OS/2")
             version = self.read_ushort()
@@ -356,14 +332,12 @@ class TTFontFile:
                 self.descent = yMin * scale
             self.capHeight = self.ascent
 
-        self.stemV = 50 + int(pow((usWeightClass / 65.0), 2))
+        self.stemV = 50 + int(pow((usWeightClass / 65), 2))
 
-        #################/
         # post - PostScript table
-        #################/
         self.seek_table("post")
         self.skip(4)
-        self.italicAngle = self.read_short() + self.read_ushort() / 65536.0
+        self.italicAngle = self.read_short() + self.read_ushort() / 65536
         self.underlinePosition = self.read_short() * scale
         self.underlineThickness = self.read_short() * scale
         isFixedPitch = self.read_ulong()
@@ -371,36 +345,30 @@ class TTFontFile:
         self.flags = 4
 
         if self.italicAngle != 0:
-            self.flags = self.flags | 64
+            self.flags |= 64
         if usWeightClass >= 600:
-            self.flags = self.flags | 262144
+            self.flags |= 262144
         if isFixedPitch:
-            self.flags = self.flags | 1
+            self.flags |= 1
 
-        #################/
         # hhea - Horizontal header table
-        #################/
         self.seek_table("hhea")
         self.skip(32)
         metricDataFormat = self.read_ushort()
         if metricDataFormat != 0:
             raise RuntimeError(
-                "Unknown horizontal metric data format: " + metricDataFormat
+                f"Unknown horizontal metric data format: {metricDataFormat}"
             )
         numberOfHMetrics = self.read_ushort()
         if numberOfHMetrics == 0:
             raise RuntimeError("Number of horizontal metrics is 0")
 
-        #################/
         # maxp - Maximum profile table
-        #################/
         self.seek_table("maxp")
         self.skip(4)
         numGlyphs = self.read_ushort()
 
-        #################/
         # cmap - Character to glyph index mapping table
-        #################/
         cmap_offset = self.seek_table("cmap")
         self.skip(2)
         cmapTableCount = self.read_ushort()
@@ -431,9 +399,9 @@ class TTFontFile:
 
         if not unicode_cmap_offset and not unicode_cmap_offset12:
             raise RuntimeError(
-                "Font ("
-                + self.filename
-                + ") does not have cmap for Unicode (platform 3, encoding 1, format 4, or platform 3, encoding 10, format 12, or platform 0, any encoding, format 4)"
+                f"Font ({self.filename}) does not have cmap for Unicode (platform 3, "
+                f"encoding 1, format 4, or platform 3, encoding 10, format 12, or "
+                f"platform 0, any encoding, format 4)"
             )
 
         glyphToChar = {}
@@ -443,14 +411,9 @@ class TTFontFile:
         else:
             self.getCMAP4(unicode_cmap_offset, glyphToChar, charToGlyph)
 
-        #################/
         # hmtx - Horizontal metrics table
-        #################/
         self.getHMTX(numberOfHMetrics, numGlyphs, glyphToChar, scale)
 
-    ############################################/
-    ############################################/
-
     def makeSubset(self, file, subset):
         self.filename = file
         with open(file, "rb") as self.fh:
@@ -466,33 +429,25 @@ class TTFontFile:
             self.maxUni = 0
             self.readTableDirectory()
 
-            #################/
             # head - Font header table
-            #################/
             self.seek_table("head")
             self.skip(50)
             indexToLocFormat = self.read_ushort()
             # pylint: disable=unused-variable
             glyphDataFormat = self.read_ushort()
 
-            #################/
             # hhea - Horizontal header table
-            #################/
             self.seek_table("hhea")
             self.skip(32)
             metricDataFormat = self.read_ushort()
             orignHmetrics = numberOfHMetrics = self.read_ushort()
 
-            #################/
             # maxp - Maximum profile table
-            #################/
             self.seek_table("maxp")
             self.skip(4)
             numGlyphs = self.read_ushort()
 
-            #################/
             # cmap - Character to glyph index mapping table
-            #################/
             cmap_offset = self.seek_table("cmap")
             self.skip(2)
             cmapTableCount = self.read_ushort()
@@ -521,9 +476,9 @@ class TTFontFile:
 
             if not unicode_cmap_offset and not unicode_cmap_offset12:
                 raise RuntimeError(
-                    "Font ("
-                    + self.filename
-                    + ") does not have cmap for Unicode (platform 3, encoding 1, format 4, or platform 3, encoding 10, format 12, or platform 0, any encoding, format 4)"
+                    f"Font ({self.filename}) does not have cmap for Unicode "
+                    f"(platform 3, encoding 1, format 4, or platform 3, encoding 10, "
+                    f"format 12, or platform 0, any encoding, format 4)"
                 )
 
             glyphToChar = {}
@@ -535,15 +490,11 @@ class TTFontFile:
 
             self.charToGlyph = charToGlyph
 
-            #################/
             # hmtx - Horizontal metrics table
-            #################/
             scale = 1  # not used
             self.getHMTX(numberOfHMetrics, numGlyphs, glyphToChar, scale)
 
-            #################/
             # loca - Index to location
-            #################/
             self.getLOCA(indexToLocFormat, numGlyphs)
 
             subsetglyphs = [(0, 0)]  # special "sorted dict"!
@@ -563,7 +514,9 @@ class TTFontFile:
             subsetglyphs.sort()
             glyphSet = {}
             n = 0
-            fsLastCharIndex = 0  # maximum Unicode index (character code) in this font, according to the cmap subtable for platform ID 3 and platform- specific encoding ID 0 or 1.
+            # maximum Unicode index (character code) in this font, according to the cmap
+            # subtable for platform ID 3 and platform- specific encoding ID 0 or 1.
+            fsLastCharIndex = 0
             for originalGlyphIdx, uni in subsetglyphs:
                 fsLastCharIndex = max(fsLastCharIndex, uni)
                 glyphSet[originalGlyphIdx] = n  # old glyphID to new glyphID
@@ -676,7 +629,7 @@ class TTFontFile:
             for subrange in range_:
                 cmap.append(
                     0
-                )  # idRangeOffset[segCount]      Offset in bytes to glyph indexArray, or 0
+                )  # idRangeOffset[segCount]   Offset in bytes to glyph indexArray, or 0
 
             cmap.append(0)  # idRangeOffset of last Segment
             for subrange, glidx in range_:
@@ -691,7 +644,8 @@ class TTFontFile:
                     try:
                         cmapstr += pack(">h", cm)
                     except StructError:
-                        # cmap value too big to fit in a short (h), putting it in an unsigned short (H):
+                        # cmap value too big to fit in a short (h),
+                        # putting it in an unsigned short (H):
                         cmapstr += pack(">H", -cm)
             self.add("cmap", cmapstr)
 
@@ -718,7 +672,7 @@ class TTFontFile:
                     glyphPos = self.glyphPos[originalGlyphIdx]
                     glyphLen = self.glyphPos[originalGlyphIdx + 1] - glyphPos
                 except IndexError:
-                    warnings.warn("Missing glyph %s in %s" % (originalGlyphIdx, file))
+                    warnings.warn(f"Missing glyph {originalGlyphIdx} in {file}")
                     glyphLen = 0
 
                 if glyfLength < self.maxStrLenRead:
@@ -754,9 +708,7 @@ class TTFontFile:
                             )
                         except KeyError:
                             data = 0
-                            warnings.warn(
-                                "Missing glyph data %s in %s" % (glyphIdx, file)
-                            )
+                            warnings.warn(f"Missing glyph data {glyphIdx} in {file}")
                         pos_in_glyph += 4
                         if flags & GF_WORDS:
                             pos_in_glyph += 4
@@ -820,7 +772,6 @@ class TTFontFile:
         stm = self.endTTFile("")
         return stm
 
-    #########################################
     # Recursively get composite glyphs
     def getGlyphs(self, originalGlyphIdx, nonlocals):
         # &start, &glyphSet, &subsetglyphs)
@@ -862,8 +813,6 @@ class TTFontFile:
                 elif flags & GF_TWOBYTWO:
                     self.skip(8)
 
-    #########################################
-
     def getHMTX(self, numberOfHMetrics, numGlyphs, glyphToChar, scale):
         start = self.seek_table("hmtx")
         aw = 0
@@ -878,7 +827,7 @@ class TTFontFile:
         nCharWidths = 0
         if (numberOfHMetrics * 4) < self.maxStrLenRead:
             data = self.get_chunk(start, (numberOfHMetrics * 4))
-            arr = unpack(">%dH" % (len(data) // 2), data)
+            arr = unpack(f">{len(data) // 2}H", data)
         else:
             self.seek(start)
         for glyph in range(numberOfHMetrics):
@@ -892,14 +841,15 @@ class TTFontFile:
             if glyph in glyphToChar or glyph == 0:
                 if aw >= (1 << 15):
                     aw = 0  # 1.03 Some (arabic) fonts have -ve values for width
-                    # although should be unsigned value - comes out as e.g. 65108 (intended -50)
+                    # although should be unsigned value
+                    # - comes out as e.g. 65108 (intended -50)
                 if glyph == 0:
                     self.defaultWidth = scale * aw
                     continue
 
                 for char in glyphToChar[glyph]:
                     if char not in (0, 65535):
-                        w = int(round(scale * aw + 0.001))  # ROUND_HALF_UP
+                        w = round(scale * aw + 0.001)  # ROUND_HALF_UP
                         if w == 0:
                             w = 65535
                         if char < 196608:
@@ -909,14 +859,14 @@ class TTFontFile:
                             nCharWidths += 1
 
         data = self.get_chunk((start + numberOfHMetrics * 4), (numGlyphs * 2))
-        arr = unpack(">%dH" % (len(data) // 2), data)
+        arr = unpack(f">{len(data) // 2}H", data)
         diff = numGlyphs - numberOfHMetrics
         for pos in range(diff):
             glyph = pos + numberOfHMetrics
             if glyph in glyphToChar:
                 for char in glyphToChar[glyph]:
                     if char not in (0, 65535):
-                        w = int(round(scale * aw + 0.001))  # ROUND_HALF_UP
+                        w = round(scale * aw + 0.001)  # ROUND_HALF_UP
                         if w == 0:
                             w = 65535
                         if char < 196608:
@@ -946,16 +896,16 @@ class TTFontFile:
         self.glyphPos = []
         if indexToLocFormat == 0:
             data = self.get_chunk(start, (numGlyphs * 2) + 2)
-            arr = unpack(">%dH" % (len(data) // 2), data)
+            arr = unpack(f">{len(data) // 2}H", data)
             for n in range(numGlyphs):
-                self.glyphPos.append((arr[n] * 2))  # n+1 !?
+                self.glyphPos.append(arr[n] * 2)  # n+1 !?
         elif indexToLocFormat == 1:
             data = self.get_chunk(start, (numGlyphs * 4) + 4)
-            arr = unpack(">%dL" % (len(data) // 4), data)
+            arr = unpack(f">{len(data) // 4}L", data)
             for n in range(numGlyphs):
-                self.glyphPos.append((arr[n]))  # n+1 !?
+                self.glyphPos.append(arr[n])  # n+1 !?
         else:
-            raise RuntimeError("Unknown location table format " + indexToLocFormat)
+            raise RuntimeError(f"Unknown location table format {indexToLocFormat}")
 
     # CMAP Format 4
     def getCMAP4(self, unicode_cmap_offset, glyphToChar, charToGlyph):
@@ -1036,10 +986,10 @@ class TTFontFile:
         searchRange = 1
         entrySelector = 0
         while searchRange * 2 <= numTables:
-            searchRange = searchRange * 2
-            entrySelector = entrySelector + 1
+            searchRange *= 2
+            entrySelector += 1
 
-        searchRange = searchRange * 16
+        searchRange *= 16
         rangeShift = numTables * 16 - searchRange
 
         # Header
@@ -1077,14 +1027,3 @@ class TTFontFile:
         chk = pack(">HH", checksum[0], checksum[1])
         stm = self.splice(stm, (head_start + 8), chk)
         return stm
-
-
-def str_pad(s, pad_length=0, pad_char=" ", pad_type=+1):
-    # pad left
-    if pad_type < 0:
-        return s.rjust(pad_length, pad_char)
-    # pad right
-    if pad_type > 0:
-        return s.ljust(pad_length, pad_char)
-    # pad both
-    return s.center(pad_length, pad_char)
